import os

CONFIG_PATH = os.path.realpath(os.path.expanduser('~') + '/.config/pystickynote/pysn.conf')
NOTES_PATH = os.path.realpath(os.path.expanduser('~') + '/.config/pystickynote/notes.json')
PATH_DIR = os.path.realpath(os.path.expanduser('~') + '/.config/pystickynote/')
